<?php
/**
 * A command for the "home" page
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebDoFormCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set special description
		$this->setObjectDescription("Command for handling forms on a centralized place");

		// Create unique ID number
		$this->createUniqueID();

		// Clean up a little
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance		An instance of a command resolver class
	 * @return	$commandInstance		An instance a prepared command class
	 */
	public final static function createWebDoFormCommand (CommandResolver $resolverInstance) {
		// Get new instance
		$commandInstance = new WebDoFormCommand();

		// Set the application instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the given command with given request and response objects
	 *
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @param	$responseInstance		An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Should never be executed...
		echo "<strong>This should never be executed!</strong><pre>";
		debug_print_backtrace();
		die("</pre>Good bye...");
	}
}

// [EOF]
?>
