<?php
/**
 * This class contains object attributes which we can now send together to
 * other classes
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class SerializationContainer extends FrameworkArrayObject {
	/**
	 * Public constructor, if you like to have an object of this class...
	 *
	 * @return	void
	 */
	public function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Create a SerializationContainer object by applying the limitations
	 * in $limitInstance on $object. The resulting data container will only
	 * hold the attributed and their values which we have specified in
	 * the limitation object.
	 *
	 * @param		$limitInstance			The instance to the object ObjectLimits
	 * @param		$object				The origin object. We don't touch it here.
	 * @return	$containerInstance		An instance of SerializationContainer
	 * @throws	GetterNotFoundException	If a getter was not found
	 */
	public final static function createSerializationContainer (ObjectLimits $limitInstance, FrameworkInterface $object) {
		// Get an instance
		$containerInstance = new SerializationContainer();

		// Iterate through the whole limitation array
		for ($idx = $limitInstance->getLimitArray()->getIterator(); $idx->valid(); $idx->next()) {
			// Get current item from list
			$curr = ucfirst($idx->current());

			// Is the required method available?
			if (method_exists($object, sprintf("get%s", $curr))) {
				// Generate a command for getting it
				$eval = sprintf("\$value = \$object->get%s();",
					$curr
				);

				// Debug eval command
				if (defined('DEBUG_EVAL')) $limitInstance->getDebugInstance()->output(sprintf("[%s:] Constructed PHP command: <pre><em>%s</em></pre><br />\n",
					$this->__toString(),
					htmlentities($eval)
				));

				// Run it
				eval($eval);

				// Add this item to the container list
				$containerInstance->append(array(
					'name'  => $curr,
					'value' => $value
				));
			} else {
				// Throw an exception
				throw new GetterNotFoundException(array($object, $curr), self::EXCEPTION_GETTER_IS_MISSING);
			}
		} // END - for

		// Return container instance
		return $containerInstance;
	}
}

// [EOF]
?>
