<?php
/**
 * An general object factory
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ObjectFactory extends BaseFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set object description
		$this->setObjectDescription("Simple generic object factory");

		// Create unique ID number
		$this->createUniqueID();
	}

	/**
	 * Creates a new object given by the name or throws an exception if
	 * the class was not found. No parameters for the object are currently
	 * supported.
	 *
	 * @param	$className				Name of the class we shall construct
	 * @return	$objectInstance			An instance of the requested object
	 * @throws	ClassNotFoundException	If the requested class was not found
	 * @throws	EmptyVariableException	If a variable is empty unexpectly
	 */
	public final static function createObjectByName ($className) {
		// First get an instance of this factory
		$factoryInstance = new ObjectFactory();

		// Is the class name valid and is the class there?
		if (empty($className)) {
			// Throw an exception here
			throw new EmptyVariableException(array($factoryInstance, 'className'), self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} elseif (!class_exists($className)) {
			// Then throw an exception
			throw new ClassNotFoundException(array($factoryInstance, $className), self::EXCEPTION_CLASS_NOT_FOUND);
		}

		// Then Prepare the eval() command
		$eval = sprintf("\$objectInstance = %s::create%s();",
			$className,
			$className
		);

		// Run the command
		eval($eval);

		// Return the prepared instance
		return $objectInstance;
	}

	/**
	 * Creates an object by it's configured name
	 *
	 * @param	$configEnttry			Configuration entry to read
	 * @return	$objectInstance			An instance of the requested object
	 */
	public final static function createObjectByConfiguredName ($configEntry) {
		// Read the configuration entry
		$className = FrameworkConfiguration::getInstance()->readConfig($configEntry);

		// Send this to the other factory...
		$objectInstance = self::createObjectByName($className);

		// Return the instance
		return $objectInstance;
	}
}

// [EOF]
?>
